/**
@license
Copyright 2018 The Advanced REST client authors <arc@mulesoft.com>
Licensed under the Apache License, Version 2.0 (the "License"); you may not
use this file except in compliance with the License. You may obtain a copy of
the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
License for the specific language governing permissions and limitations under
the License.
*/
import {PolymerElement} from '../../@polymer/polymer/polymer-element.js';
import '../../@advanced-rest-client/arc-icons/arc-icons.js';
import '../../@polymer/iron-flex-layout/iron-flex-layout.js';
import '../../@polymer/paper-styles/shadow.js';
import '../../@polymer/paper-button/paper-button.js';
import '../../@polymer/paper-menu-button/paper-menu-button.js';
import '../../@polymer/paper-icon-button/paper-icon-button.js';
import '../../@polymer/paper-listbox/paper-listbox.js';
import '../../@polymer/paper-item/paper-item.js';
import '../../@polymer/paper-item/paper-item-body.js';
import {RestApisItemMixin} from './rest-apis-item-mixin.js';
import {html} from '../../@polymer/polymer/lib/utils/html-tag.js';
/**
 * Displays a single list item for REST APIs list screen.
 *
 * ### Example
 *
 * ```html
 * <rest-apis-list-item item="{...}"></rest-apis-list-panel>
 * ```
 *
 * ### Styling
 * `<rest-apis-list-item>` provides the following custom properties and mixins for styling:
 *
 * Custom property | Description | Default
 * ----------------|-------------|----------
 * `--rest-apis-list-item` | Mixin applied to the element | `{}`
 * `--rest-apis-list-item-action-button` | Mixin applied to the visible accrion button | `{}`
 *
 * @polymer
 * @customElement
 * @memberof UiElements
 * @demo demo/index.html
 * @appliesMixin RestApisItemMixin
 */
class RestApisListItem extends RestApisItemMixin(PolymerElement) {
  static get template() {
    return html`
    <style>
    :host {
      @apply --arc-font-body1;
      display: block;
      color: var(--rest-apis-list-item-color, rgba(0, 0, 0, 0.87));
    }

    h3 {
      font-size: 16px;
      font-weight: 400;
      padding: 0;
      margin: 0;
    }

    .meta {
      margin: 0;
      padding: 0;
      margin-right: 12px;
    }

    .api-icon {
      color: var(--rest-apis-list-item-icon-color, #73cfee);
    }

    .details {
      @apply --layout-horizontal;
    }
    </style>
    <paper-item>
      <paper-item-body two-line="">
        <h3>[[item.title]]</h3>
        <div secondary="" class="details">
          <p class="meta">Version: [[item.latest]]</p>
          <p class="meta">[[item._id]]</p>
        </div>
      </paper-item-body>
      <paper-button noink="[[noink]]" on-click="requestOpen" class="open-button">Open</paper-button>
      <paper-menu-button close-on-activate="">
        <paper-icon-button icon="arc:more-vert" slot="dropdown-trigger"></paper-icon-button>
        <paper-listbox slot="dropdown-content">
          <paper-item on-click="requestDelete">Delete</paper-item>
        </paper-listbox>
      </paper-menu-button>
    </paper-item>
`;
  }

  static get is() {
    return 'rest-apis-list-item';
  }
}
window.customElements.define(RestApisListItem.is, RestApisListItem);
